@@ -99,7 +99,7 @@ static void song_view_showed(ClutterTimeline* t, gpointer sequencer){
 
 	int fd_name; //Checking if there are nameXX.spx
 	int fd_intro; //Checking if there are introXX.spx
-	gchar* mentor_tells="";
+	gchar* mentor_tells;
 
 	//If song doesn't have "name_XX.spx" look for "intro_XX.spx"
 	gchar *filepath1;
@@ -503,21 +503,22 @@ static void icon_offset_from_json(char* filename, gfloat* x,gfloat* y, gfloat* w
   g_assert (object != NULL);
 
 
+  //Human readable file contains pixels as integers. Clutter is handling pixels as floats.
   node = json_object_get_member (object, "x");
   if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE)
-    *x = (gfloat) json_node_get_int (node);
+    *x = json_node_get_int (node) * 1.0;
 
   node = json_object_get_member (object, "y");
   if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE)
-    *y = (gfloat) json_node_get_int (node);
+    *y = json_node_get_int (node) * 1.0;
 
   node = json_object_get_member (object, "width");
   if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE)
-    *w = (gfloat) json_node_get_int (node);
+    *w = json_node_get_int (node) * 1.0;
 
   node = json_object_get_member (object, "height");
   if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE)
-    *h = (gfloat) json_node_get_int (node);
+    *h = json_node_get_int (node) * 1.0;
 
   g_object_unref (parser);
 }
@@ -578,7 +579,7 @@ GList* song_init_songs_from_disk(){
 		//There will be more optional folders. TODO
 		
 		gchar* base_path=NULL; //this is where we try found songs
-		gchar* song_pack=""; //This is additional information we store in song
+		const gchar* song_pack; //This is additional information we store in song
 		if (i==0)
 			{
 			song_pack="easy";
@@ -595,7 +596,7 @@ GList* song_init_songs_from_disk(){
 			song_pack="own";
 			base_path=g_strdup_printf("%s/.jammo/songs/",home);
 			}
-
+		else song_pack="";
 		//printf("base_path='%s'\n",base_path);
 		////////////////////
 
