@@ -25,6 +25,6 @@ void theme_stop_all_icon_animations(jammo_theme* theme);
 void theme_play_all_icon_animations(jammo_theme* theme);
 void delete_theme(jammo_theme* theme);
 
-ClutterActor* theme_give_sample_button_for_this_theme_and_variation_for_this_id(jammo_theme* theme, gchar* themename, guint variation, guint id);
+ClutterActor* theme_give_sample_button_for_this_theme_and_variation_for_this_id(jammo_theme* theme, const gchar* themename, guint variation, guint id);
 
 #endif /* __THEME_H_ */
