@@ -12,13 +12,8 @@ This file contains the functionality of the avatar editor.
 
 void start_avatar_editor();
 void set_avatar(Avatar*, ClutterActor*, ClutterActor*, char*);
-void avatar_goto_communitymenu(TangleButton *tanglebutton, gpointer none);
-void avatar_goto_startmenu(TangleButton *tanglebutton, gpointer none);
-void change_body_color();
-void change_hair_color();
-void change_hair_type();
-void change_head();
-void change_instrument();
-void pressed(ClutterActor*);
+gboolean avatar_goto_communitymenu(TangleButton *tanglebutton, gpointer none);
+gboolean avatar_goto_startmenu(TangleButton *tanglebutton, gpointer none);
+
 
 #endif
