@@ -18,13 +18,9 @@
 
 static gboolean renaming_loop = FALSE;
 
-// milliseconds 1500
-#define DURATION_OF_LONG_CLICK 1000
-
 //Long click:  rename the item
-static gboolean tap_and_hold_function(gpointer user_data) {
-
-	ClutterActor* actor=CLUTTER_ACTOR(user_data);
+void song_on_held_function(TangleButton* button, gpointer user_data) {
+	ClutterActor* actor=CLUTTER_ACTOR(button);
 	g_object_set_data(G_OBJECT(actor),"handler_for_longclick",GUINT_TO_POINTER(0));
 
 	const char* filename = clutter_actor_get_name(actor);
@@ -39,12 +35,12 @@ static gboolean tap_and_hold_function(gpointer user_data) {
 	}
 
 	rename_loop(actor, type);
-	return FALSE;
 }
 
 //Short click: play
-static void name_clicked(ClutterActor* actor) {
+void song_on_clicked_function(TangleButton* button, gpointer user_data) {
 
+	ClutterActor* actor = CLUTTER_ACTOR(button);
 	const char* filename = clutter_actor_get_name(actor);
 	const char* projects = configure_get_projects_directory();
 	const char* finalized = configure_get_finalized_directory();
@@ -71,26 +67,6 @@ static void name_clicked(ClutterActor* actor) {
 }
 
 
-gboolean song_name_press_action (ClutterActor* actor, ClutterButtonEvent *event) {
-	guint holding_event_source_id = g_timeout_add(DURATION_OF_LONG_CLICK, tap_and_hold_function, actor);
-	g_object_set_data(G_OBJECT(actor),"handler_for_longclick",GUINT_TO_POINTER(holding_event_source_id));
-
-	return TRUE;
-}
-
-
-gboolean song_name_release_action (ClutterActor* actor, ClutterButtonEvent *event) {
-	guint holding_event_source_id= GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(actor),"handler_for_longclick"));
-
-	if (holding_event_source_id) {
-		g_source_remove(holding_event_source_id);
-		g_object_set_data(G_OBJECT(actor),"handler_for_longclick",GUINT_TO_POINTER(0));
-
-		//If tap_and_hold_function is triggered, we do not want call this:
-		name_clicked(actor);
-	}
-	return TRUE;
-}
 
 
 
