@@ -1,6 +1,7 @@
 #ifndef COMMUNITY_UTILITIES_H
 #define COMMUNITY_UTILITIES_H
 
+#include <tangle.h>
 #include "../jammo.h"
 #include "../../configure.h"
 #include <libintl.h>
@@ -68,6 +69,8 @@ typedef struct{
 */
 gboolean song_name_press_action(ClutterActor* actor, ClutterButtonEvent *event);
 gboolean song_name_release_action(ClutterActor* actor, ClutterButtonEvent *event);
+void song_on_held_function(TangleButton* button, gpointer user_data);
+void song_on_clicked_function(TangleButton* button, gpointer user_data);
 void rename_loop(ClutterActor *loopName, int type); 
 void play_selected_loop(ClutterActor*);
 void show_song_label(show_label_params *params);
