@@ -13,8 +13,8 @@ This file contains the functionality of Help menu.
 #define MAX_COMMENTS 15
 
 void start_helpdesk(void);
-void helpdesk_goto_communitymenu(TangleButton *tanglebutton, gpointer none);
-void helpdesk_goto_startmenu(TangleButton *tanglebutton, gpointer none);
+gboolean helpdesk_goto_communitymenu(TangleButton *tanglebutton, gpointer none);
+gboolean helpdesk_goto_startmenu(TangleButton *tanglebutton, gpointer none);
 void end_helpdesk(void);
 
 void helpdesk_get_questions(void);
@@ -30,6 +30,6 @@ void helpdesk_add_question(void);
 
 void helpdesk_show_question_view(ClutterActor *actor);
 void helpdesk_show_helpdesk_view(void);
-void helpdesk_show_addquestion_view(void);
+gboolean helpdesk_show_addquestion_view(TangleActor* actor, gpointer data);
 
 #endif 
