@@ -50,6 +50,9 @@
 //We want disconnect this when leaving
 static gulong handler_for_sequencer_stop = 0;
 
+//We need to know, are we playing with piano keys or drumset
+static gboolean using_drumkit=FALSE;
+
 //For keyboard
 static int UPPER_OCTAVE=3;
 // TRANSPOSE is used to transpose keyboard to a different key
@@ -149,13 +152,13 @@ static void visualize_playback(JammoInstrumentTrack* track, gint note, gpointer
 	if (notename[1]=='#')
 		sharp=TRUE;
 
-	if (note<=12*UPPER_OCTAVE)
+	if (note<12*(UPPER_OCTAVE+1))
 		bottom=TRUE;
 
-	const char* id  = g_strdup_printf("instrument_key_%c%s%s",notename[0],sharp?"s":"",bottom?"2":"");
+	const char* id  = g_strdup_printf("instrument_%s_%c%s%s",using_drumkit?"drum":"key",notename[0],sharp?"s":"",bottom?"2":"");
 	//printf("looking for id '%s'\n",id);
 	ClutterActor* key = jammo_get_actor_by_id(id);
-
+	//printf("key id '%s'\n",id);
 
 	//Swap normal and interactive textures when note-ON.
 	//And change back when note-OFF.
@@ -576,10 +579,14 @@ void instrument_gui_start (JammoMiditrackView* miditrack_view, TangleWidget* sli
 		clutter_actor_hide(jammo_get_actor_by_id("instrument-slider"));
 		clutter_actor_hide(jammo_get_actor_by_id("instrument-two-rows-keyboard"));
 		clutter_actor_hide(jammo_get_actor_by_id("instrument-drumset"));
-		if (type==JAMMO_INSTRUMENT_TYPE_DRUMKIT)
+		if (type==JAMMO_INSTRUMENT_TYPE_DRUMKIT){
 			clutter_actor_show(jammo_get_actor_by_id("instrument-drumset"));
-		else
+			using_drumkit=TRUE;
+		}
+		else{
 			clutter_actor_show(jammo_get_actor_by_id("instrument-two-rows-keyboard"));
+			using_drumkit=FALSE;
+		}
 
 		ad_hoc_instrument_track = jammo_instrument_track_new (type);
 		jammo_sequencer_add_track (ad_hoc_sequencer, JAMMO_TRACK (ad_hoc_instrument_track));
