@@ -160,9 +160,10 @@ gboolean add_song_to_list(char* loopName, int numberOfSongs, guint32 user_id){
 	g_signal_connect_swapped(reviewButton, "clicked", G_CALLBACK(review_selected_song), 
 				clutter_actor_get_parent(reviewButton));
 
-	g_signal_connect_swapped(songName, "button-press-event", G_CALLBACK(song_name_press_action), songName);
-	g_signal_connect_swapped(songName, "button-release-event", G_CALLBACK(song_name_release_action), songName);
-	
+	g_signal_connect(songName, "clicked", G_CALLBACK(song_on_clicked_function), NULL);
+	g_object_set(songName, "hold-timeout", 1500, NULL);
+	g_signal_connect(songName, "held", G_CALLBACK(song_on_held_function), NULL);
+
 	if(label != 0){	
 		strcpy(labelParams->parentview, "jammosongs");
 		g_signal_connect_swapped(label, "clicked", G_CALLBACK(show_song_label), (gpointer)labelParams);
