@@ -111,9 +111,11 @@ gboolean add_loop_to_list(char* name, int numberOfLoops){
 	
 	g_signal_connect_swapped(importButton, "clicked", G_CALLBACK(import_selected_loop), 
 				clutter_actor_get_parent(importButton));
-	
-	g_signal_connect_swapped(loopName, "button-press-event", G_CALLBACK(song_name_press_action), loopName);
-	g_signal_connect_swapped(loopName, "button-release-event", G_CALLBACK(song_name_release_action), loopName);
+
+	g_signal_connect(loopName, "clicked", G_CALLBACK(song_on_clicked_function), NULL);
+	g_object_set(loopName, "hold-timeout", 1500, NULL);
+	g_signal_connect(loopName, "held", G_CALLBACK(song_on_held_function), NULL);
+
 	
 	clutter_container_add_actor(list, CLUTTER_ACTOR(listContainer));
 	
