@@ -10,7 +10,7 @@ This file contains the functionality of JamMo Sounds menu.
 
 
 void start_jammosounds();
-void end_jammosounds(TangleButton *tanglebutton, gpointer none);
+gboolean end_jammosounds(TangleButton *tanglebutton, gpointer none);
 gboolean add_loop_to_list(char* loop_name, int number);
 void import_selected_loop(ClutterActor*);
 
