@@ -108,15 +108,14 @@ static void add_dropped_listener(ClutterActor* sample_button, gpointer task){
 void level1_task1_started(JammoGameTask* task) {
 
 	//disable melodical_sample_looper
-	//jammo_chum_disable_actor(sequencer_loop_get_nth_sample_looper(2)); //TODO: disabling container should disable elements
-	clutter_actor_hide(sequencer_loop_get_nth_sample_looper(2));
+	jammo_chum_disable_all_actors(sequencer_loop_get_nth_sample_looper(2));
 
 	//disable/hide track2 entirely (it will used on task6)
 	ClutterActor* track_view2 = jammo_get_actor_by_id("track-view2");
-	jammo_chum_disable_actor(track_view2); //FIXME: disabled track looks like enabled track
+	jammo_chum_disable_all_actors(track_view2);
 	ClutterActor* track2_controls = jammo_get_actor_by_id("controls-for-track2-level1");
-	jammo_chum_disable_actor(track2_controls); //FIXME: buttons are still reactive etc
-	g_object_set(track_view2,"disabled-slots-begin",8,NULL);
+	jammo_chum_disable_all_actors(track2_controls);
+	g_object_set(track_view2,"disabled-slots-begin",8*4,NULL);
 
 	//assign sample-buttons to task
 	ClutterActor* rhytmical_sample_looper  = sequencer_loop_get_nth_sample_looper(1);
@@ -124,7 +123,7 @@ void level1_task1_started(JammoGameTask* task) {
 
 	//Disable dropping for editing track1
 	ClutterActor* track_view = jammo_get_actor_by_id("track-view1");
-	g_object_set(track_view,"disabled-slots-begin",8,NULL);
+	g_object_set(track_view,"disabled-slots-begin",8*4,NULL);
 
 	//When dragging ends, screen is restored to loop-view
 	clutter_container_foreach(CLUTTER_CONTAINER(sequencer_loop_get_nth_sample_looper(1)), add_dropped_listener, task);
@@ -427,9 +426,9 @@ void level1_task4_completed(JammoGameTask* task) {
 	cem_add_to_log("level1-task4: completed",J_LOG_DEBUG);
 	//Show (and flash) melodic-track
 	ClutterActor* track_view2 = jammo_get_actor_by_id("track-view2");
-	jammo_chum_enable_actor(track_view2);
+	jammo_chum_enable_all_actors(track_view2);
 	ClutterActor* track2_controls = jammo_get_actor_by_id("controls-for-track2-level1");
-	jammo_chum_enable_actor(track2_controls);
+	jammo_chum_enable_all_actors(track2_controls);
 
 	//Changing size of elements inside container, affects whole container. Maybe there should be some other effect.
 	jammo_clutter_actor_flash(track_view2);
@@ -448,8 +447,7 @@ void level1_task5_started(JammoGameTask* task) {
 	sequencer_change_to_loop_view(NULL,NULL);
 
 	//enable melodical_sample_looper
-	//jammo_chum_enable_actor(sequencer_loop_get_nth_sample_looper(2)); //TODO: disabling container should disable elements
-	clutter_actor_show(sequencer_loop_get_nth_sample_looper(2));
+	jammo_chum_enable_all_actors(sequencer_loop_get_nth_sample_looper(2));
 
 	//assign sample-buttons on melodical_sample_looper to this task
 	clutter_container_foreach(CLUTTER_CONTAINER( sequencer_loop_get_nth_sample_looper(2)), add_listening_act_to_this_task, task);
@@ -605,47 +603,48 @@ void level1_task7_started(JammoGameTask* task) {
 	//g_object_get(track_view,"n-slots",&n_slots,NULL);
 	//printf("n_slots: %d \n",n_slots);
 
-	gboolean free_slot[8]={TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE}; //FIXME: use n_slots
+	gboolean free_bar[8]={TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE}; //FIXME: use n_bar
 	TangleActorIterator actor_iterator;
 	ClutterActor* child;
 	
 	for (tangle_widget_initialize_actor_iterator(TANGLE_WIDGET(track_view), &actor_iterator); (child = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
 
 		guint slot = jammo_editing_track_view_get_sample_button_slot(JAMMO_EDITING_TRACK_VIEW(track_view),JAMMO_SAMPLE_BUTTON(child));
-
+		guint bar = slot / 4 ;
 		float width = clutter_actor_get_width(child);
 		//printf("reserved slots %d, %f\n",slot, width); //width is 75=slot
-		free_slot[slot]=FALSE;
-		if (width>80) //FIXME: check width of slots
-			free_slot[slot+1]=FALSE;
+		free_bar[bar]=FALSE;
+		if (width>80) //FIXME: check width of bar
+			free_bar[bar+1]=FALSE;
 		if (width>160)
-			free_slot[slot+2]=FALSE;
+			free_bar[bar+2]=FALSE;
 		if (width>310)
-			free_slot[slot+3]=FALSE;
+			free_bar[bar+3]=FALSE;
 	}
 
-	int index_counter=-1;
+	int index_counter=-1; //on bars.
 	int i;
-	for(i=0;i<8;i++) { //FIXME:use n_slots as max
-		if (free_slot[i]){
+	for(i=0;i<8;i++) { //FIXME:use n_bars as max
+		if (free_bar[i]){
 			index_counter=i;
 			break;
 			}
 	}
 	if (index_counter==-1){ //means no free space
-		//remove sample from slot 0
+		//remove sample from beats 0 and 3 (it is possible there are on waltz-sample on beats 0,1,2, and funny is four beat wide)
 		jammo_editing_track_view_remove_jammo_sample_button_from_slot(JAMMO_EDITING_TRACK_VIEW(track_view), 0);
+		jammo_editing_track_view_remove_jammo_sample_button_from_slot(JAMMO_EDITING_TRACK_VIEW(track_view), 3);
 		index_counter=0;
 	}
 
-	//Now we have guaranteed empty slot
-	jammo_editing_track_view_add_jammo_sample_button(JAMMO_EDITING_TRACK_VIEW(track_view), funny, index_counter);
+	//Now we have guaranteed empty bar.
+	jammo_editing_track_view_add_jammo_sample_button(JAMMO_EDITING_TRACK_VIEW(track_view), funny, index_counter*4);
 
 	g_signal_connect(funny,"listened", G_CALLBACK(level1_task7_funny_listened),task);
 
 	//mentor blocks sight
 	float mentor_place=-240.0;
-	mentor_place+=50*index_counter; //mentor_place= slot_index*width_of_slot * mentor_scale (75 * 1.5 = 50) //TODO: correct values
+	mentor_place+=50*index_counter*4; //mentor_place= slot_index*width_of_slot * mentor_scale (75 * 1.5 = 50) //TODO: use correct values
 
 	//mentor: oops, I put funny sample to the track, listen it.
 	jammo_mentor_speak_and_highlight_with_callback(jammo_mentor_get_default(),
