@@ -27,8 +27,7 @@ void level2_completed(JammoGameLevel* game_level) {
 
 //Task1: listening four rhythmic loops
 void level2_task1_started(JammoGameTask* task) {
-	g_print("MENTOR: Lets_rock.\n");
-	jammo_mentor_speak(jammo_mentor_get_default(), "lets_rock.spx");
+	clutter_actor_show(CLUTTER_ACTOR(jammo_mentor_get_default()));
 }
 
 void level2_task1_on_act_completed(JammoGameTask* task, const gchar* act_name, guint acts_completed) {
