@@ -24,11 +24,11 @@ static gchar *id;
 static TextField text;
 gchar filepath [150];
 
-void start_thread_view(GList* listOfMessages, gchar *id_, gchar *params, int index)
+void start_thread_view(GList* listOfMessages, gchar *id_, gchar *params, int index_parameter)
 {
 	GList *l = 0; //Iterator
 
-	selected_index 	= index;
+	selected_index = index_parameter;
 	messages 	= listOfMessages;
 	id 		= id_;
 
@@ -66,7 +66,7 @@ void start_thread_view(GList* listOfMessages, gchar *id_, gchar *params, int ind
 			messageList = CLUTTER_CONTAINER(jammo_get_actor_by_id("single-thread-list-scrollable"));		
 				
 			for(l = messages; l; l = l->next)
-			add_message_to_list(l->data, index);
+			add_message_to_list(l->data, index_parameter);
 		}
 	}
 	else
@@ -92,7 +92,7 @@ void add_message_to_list(gpointer data, int i)
 
 	if(msg->index == i)	//If the messages index is the same as i (question number, we selected) then add it to list.
 	{
-		int index = 0;
+		int index_counter = 0;
 		int MAX = 500;
 		int h = 80;
 		
@@ -130,7 +130,7 @@ void add_message_to_list(gpointer data, int i)
 		community_shrink_and_set_avatar(&avatar, CLUTTER_CONTAINER(avatarBackground));
 		clutter_container_add_actor(CLUTTER_CONTAINER(listContainer), writer);
 		
-		index = (index+1) % 3;
+		index_counter = (index_counter+1) % 3;
 
 		if(strcmp(msg->title, "") != 0){
 			ClutterActor* title = clutter_text_new_full(TEXT_LARGE, msg->title, &text_color);
@@ -155,14 +155,14 @@ void add_message_to_list(gpointer data, int i)
 		g_signal_connect_swapped(writer, "clicked", G_CALLBACK(start_profile_view), (gpointer)params);
 
 		if(msg->type == TEXT_COMMENT){
-			ClutterActor* message = clutter_text_new_full(TEXT_SMALL, msg->msg, &text_color);
-			clutter_text_set_line_wrap_mode(CLUTTER_TEXT(message), PANGO_WRAP_WORD_CHAR);
-				//clutter_actor_set_size(message,(88*7)+40, ((MAX/88)*27));
-			clutter_actor_set_width(message, (88*7)+40);
-			clutter_text_set_max_length(CLUTTER_TEXT(message), MAX);
-			clutter_actor_set_position(message, 80, 80); 
-			clutter_container_add_actor(listContainer, message);
-			h = (clutter_actor_get_height(avatarBackground) + pango_layout_get_line_count(clutter_text_get_layout(CLUTTER_TEXT(message)))*25);	
+			ClutterActor* message_actor = clutter_text_new_full(TEXT_SMALL, msg->msg, &text_color);
+			clutter_text_set_line_wrap_mode(CLUTTER_TEXT(message_actor), PANGO_WRAP_WORD_CHAR);
+				//clutter_actor_set_size(message_actor,(88*7)+40, ((MAX/88)*27));
+			clutter_actor_set_width(message_actor, (88*7)+40);
+			clutter_text_set_max_length(CLUTTER_TEXT(message_actor), MAX);
+			clutter_actor_set_position(message_actor, 80, 80);
+			clutter_container_add_actor(listContainer, message_actor);
+			h = (clutter_actor_get_height(avatarBackground) + pango_layout_get_line_count(clutter_text_get_layout(CLUTTER_TEXT(message_actor)))*25);	
 		}
 
 		if(msg->type == VOICE_COMMENT){
