@@ -18,7 +18,7 @@ enum {
 	PROP_SPEECH,
 	PROP_SPEAK_ONCE,
 	PROP_IDLE_SPEECH,
-	PROP_HIGHLIGHT,
+	PROP_DURATION,
 	PROP_OFFSET_X,
 	PROP_OFFSET_Y
 };
@@ -33,10 +33,10 @@ struct _JammoMentorActivityPrivate {
 	JammoMentor* mentor;
 	gchar* speech;
 	gchar* idle_speech;
+	guint duration;
 	gfloat offset_x;
 	gfloat offset_y;
 	guint speak_once : 1;
-	guint highlight : 1;
 };
 
 static void on_mentor_spoken(JammoMentor* mentor, const gchar* speech, gboolean interrupted, gpointer user_data);
@@ -78,9 +78,18 @@ void jammo_mentor_activity_set_speech(JammoMentorActivity* mentor_activity, cons
 	g_return_if_fail(JAMMO_IS_MENTOR_ACTIVITY(mentor_activity));
 
 	if (g_strcmp0(mentor_activity->priv->speech, speech)) {
+		g_object_freeze_notify(G_OBJECT(mentor_activity));
+
 		g_free(mentor_activity->priv->speech);
 		mentor_activity->priv->speech = g_strdup(speech);
-		g_object_notify(G_OBJECT(mentor_activity), "speech");	
+		g_object_notify(G_OBJECT(mentor_activity), "speech");
+		
+		if (speech && mentor_activity->priv->duration > 0) {
+			mentor_activity->priv->duration = 0;
+			g_object_notify(G_OBJECT(mentor_activity), "duration");
+		}
+
+		g_object_thaw_notify(G_OBJECT(mentor_activity));
 	}
 }
 
@@ -99,18 +108,28 @@ void jammo_mentor_activity_set_speak_once(JammoMentorActivity* mentor_activity,
 	}
 }
 
-gboolean jammo_mentor_activity_get_highlight(JammoMentorActivity* mentor_activity) {
-	g_return_val_if_fail(JAMMO_IS_MENTOR_ACTIVITY(mentor_activity), FALSE);
+guint jammo_mentor_activity_get_duration(JammoMentorActivity* mentor_activity) {
+	g_return_val_if_fail(JAMMO_IS_MENTOR_ACTIVITY(mentor_activity), 0);
 
-	return mentor_activity->priv->highlight;
+	return mentor_activity->priv->duration;
 }
 
-void jammo_mentor_activity_set_highlight(JammoMentorActivity* mentor_activity, gboolean highlight) {
+void jammo_mentor_activity_set_duration(JammoMentorActivity* mentor_activity, guint duration) {
 	g_return_if_fail(JAMMO_IS_MENTOR_ACTIVITY(mentor_activity));
 
-	if (mentor_activity->priv->highlight != highlight) {
-		mentor_activity->priv->highlight = highlight;
-		g_object_notify(G_OBJECT(mentor_activity), "highlight");
+	if (mentor_activity->priv->duration != duration) {
+		g_object_freeze_notify(G_OBJECT(mentor_activity));
+
+		mentor_activity->priv->duration = duration;
+		g_object_notify(G_OBJECT(mentor_activity), "duration");
+
+		if (duration > 0 && mentor_activity->priv->speech) {
+			g_free(mentor_activity->priv->speech);
+			mentor_activity->priv->speech = NULL;
+			g_object_notify(G_OBJECT(mentor_activity), "speech");
+		}
+
+		g_object_thaw_notify(G_OBJECT(mentor_activity));
 	}
 }
 
@@ -170,35 +189,26 @@ static void jammo_mentor_activity_activate(TangleActivity* activity) {
 	}
 	
 	g_return_if_fail(mentor != NULL);
-	g_return_if_fail(mentor_activity->priv->speech != NULL || mentor_activity->priv->idle_speech != NULL);
+	g_return_if_fail(mentor_activity->priv->speech != NULL ||
+	                 mentor_activity->priv->idle_speech != NULL ||
+			 mentor_activity->priv->duration > 0);
 	
 	jammo_mentor_shut_up(mentor);
 	if (mentor_activity->priv->speech) {
-		if (mentor_activity->priv->highlight) {
-			if (mentor_activity->priv->speak_once) {
-				jammo_mentor_speak_and_highlight_once_with_callback(mentor, mentor_activity->priv->speech, mentor_activity->priv->offset_x, mentor_activity->priv->offset_y, on_mentor_spoken, mentor_activity);
-			} else {
-				jammo_mentor_speak_and_highlight_with_callback(mentor, mentor_activity->priv->speech, mentor_activity->priv->offset_x, mentor_activity->priv->offset_y, on_mentor_spoken, mentor_activity);
-			}
-		 } else {
-			if (mentor_activity->priv->speak_once) {
-				jammo_mentor_speak_once_with_callback(mentor, mentor_activity->priv->speech, on_mentor_spoken, mentor_activity);
-			} else {
-				jammo_mentor_speak_with_callback(mentor, mentor_activity->priv->speech, on_mentor_spoken, mentor_activity);
-			}
+		if (mentor_activity->priv->speak_once) {
+			jammo_mentor_speak_and_highlight_once_with_callback(mentor, mentor_activity->priv->speech, mentor_activity->priv->offset_x, mentor_activity->priv->offset_y, on_mentor_spoken, mentor_activity);
+		} else {
+			jammo_mentor_speak_and_highlight_with_callback(mentor, mentor_activity->priv->speech, mentor_activity->priv->offset_x, mentor_activity->priv->offset_y, on_mentor_spoken, mentor_activity);
 		}
+	} else if (mentor_activity->priv->duration > 0) {
+		jammo_mentor_highlight_with_callback(mentor, mentor_activity->priv->offset_x, mentor_activity->priv->offset_y, mentor_activity->priv->duration, on_mentor_spoken, mentor_activity);
 	}
+	
 	if (mentor_activity->priv->idle_speech) {
 		jammo_mentor_set_idle_speech(mentor, mentor_activity->priv->idle_speech);
 	}
 }
 
-static void jammo_mentor_activity_spoken(JammoMentorActivity* mentor_activity, const gchar* speech) {
-}
-
-static void jammo_mentor_activity_interrupted(JammoMentorActivity* mentor_activity, const gchar* speech) {
-}
-
 static void jammo_mentor_activity_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
 	JammoMentorActivity* mentor_activity;
 	
@@ -217,8 +227,8 @@ static void jammo_mentor_activity_set_property(GObject* object, guint prop_id, c
 		case PROP_IDLE_SPEECH:
 			jammo_mentor_activity_set_idle_speech(mentor_activity, g_value_get_string(value));
 			break;
-		case PROP_HIGHLIGHT:
-			jammo_mentor_activity_set_highlight(mentor_activity, g_value_get_boolean(value));
+		case PROP_DURATION:
+			jammo_mentor_activity_set_duration(mentor_activity, g_value_get_uint(value));
 			break;
 		case PROP_OFFSET_X:
 			jammo_mentor_activity_set_offset_x(mentor_activity, g_value_get_float(value));
@@ -250,8 +260,8 @@ static void jammo_mentor_activity_get_property(GObject* object, guint prop_id, G
 		case PROP_IDLE_SPEECH:
 			g_value_set_string(value, mentor_activity->priv->idle_speech);
 			break;
-		case PROP_HIGHLIGHT:
-			g_value_set_boolean(value, mentor_activity->priv->highlight);
+		case PROP_DURATION:
+			g_value_set_uint(value, mentor_activity->priv->duration);
 			break;
 		case PROP_OFFSET_X:
 			g_value_set_float(value, mentor_activity->priv->offset_x);
@@ -284,9 +294,6 @@ static void jammo_mentor_activity_class_init(JammoMentorActivityClass* mentor_ac
 
 	activity_class->activate = jammo_mentor_activity_activate;
 	
-	mentor_activity_class->spoken = jammo_mentor_activity_spoken;
-	mentor_activity_class->interrupted = jammo_mentor_activity_interrupted;
-
 	/**
 	 * JammoMentorActivity:mentor:
 	 *
@@ -303,6 +310,7 @@ static void jammo_mentor_activity_class_init(JammoMentorActivityClass* mentor_ac
 	 *
 	 * The speech that the mentor should speak when the mentor_activity is executed.
 	 * Can be NULL, if the purpose of the mentor_activity is only to set idle speech.
+	 * As a side effect, setting a non-null speech resets duration back to zero.
 	 */
 	g_object_class_install_property(gobject_class, PROP_SPEECH,
 	                                g_param_spec_string("speech",
@@ -333,6 +341,45 @@ static void jammo_mentor_activity_class_init(JammoMentorActivityClass* mentor_ac
 	                                                    "The speech that the mentor should speak when an user is idling",
 	                                                    NULL,
 	                                                    G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
+	/**
+	 * JammoMentorActivity:duration:
+	 *
+	 * The duration of a movement related to highlighting.
+	 * Leave this zero, if you do not want to move a mentor when the mentor_activity is executed.
+	 * As a side effect, setting a non-zero duration resets speech back to null.
+	 */
+	g_object_class_install_property(gobject_class, PROP_DURATION,
+	                                g_param_spec_uint("duration",
+	                                                  "Duration",
+	                                                  "The duration of a movement related to highlighting",
+	                                                  0, G_MAXUINT, 0,
+	                                                  G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
+	/**
+	 * JammoMentorActivity:offset-x:
+	 *
+	 * The horizontal offset of a movement related to highlighting.
+	 * Leave both horizontal and vertivcal offset to zero, if you do not want to move a
+	 * mentor when the mentor_activity is executed.
+	 */
+	g_object_class_install_property(gobject_class, PROP_OFFSET_X,
+	                                g_param_spec_float("offset-x",
+	                                                   "Offset X",
+	                                                   "The horizontal offset of a movement related to highlighting",
+	                                                   -G_MAXFLOAT, G_MAXFLOAT, 0.0,
+	                                                   G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
+	/**
+	 * JammoMentorActivity:offset-y:
+	 *
+	 * The vertical offset of a movement related to highlighting.
+	 * Leave both horizontal and vertivcal offset to zero, if you do not want to move a
+	 * mentor when the mentor_activity is executed.
+	 */
+	g_object_class_install_property(gobject_class, PROP_OFFSET_Y,
+	                                g_param_spec_float("offset-y",
+	                                                   "Offset Y",
+	                                                   "The vertical offset of a movement related to highlighting",
+	                                                   -G_MAXFLOAT, G_MAXFLOAT, 0.0,
+	                                                   G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	/**
 	 * JammoMentorActivity::spoken:
