@@ -10,11 +10,11 @@
 
 #include "jammo-mentor.h"
 #include "../meam/jammo-sample.h"
+#include "../cem/cem.h"
 #include <time.h>
 #include <dbus/dbus-glib.h>
 #include <string.h>
 
-#include "../cem/cem.h"
 G_DEFINE_TYPE(JammoMentor, jammo_mentor, TANGLE_TYPE_BUTTON)
 
 #ifdef N900
@@ -28,12 +28,15 @@ G_DEFINE_TYPE(JammoMentor, jammo_mentor, TANGLE_TYPE_BUTTON)
 #define MCE_DEVICE_LOCKED "locked"
 #endif
 
+#define DEFAULT_DURATION 1000
+
 enum {
 	PROP_0,
 	PROP_STANDBY_SCALE,
 	PROP_ACTIVE_SCALE,
 	PROP_IDLE_SPEECH,
 	PROP_IDLE_TIMEOUT,
+	PROP_PASSIVE,
 	PROP_DEVICE_LOCKED
 };
 
@@ -44,11 +47,11 @@ struct _JammoMentorPrivate {
 	JammoMentorSpokenCallback idle_speech_spoken_callback;
 	gpointer idle_speech_spoken_user_data;
 	gulong idle_timeout;
-	gulong default_idle_timeout;
 	gchar* language;
 	
 	GList* spoken_speeches;
 	JammoSample* active_sample;
+	ClutterAnimation* active_animation;
 
 	ClutterActor* stage;
 	gulong stage_captured_event_handler_id;
@@ -59,11 +62,10 @@ struct _JammoMentorPrivate {
 	guint idle_speech_spoken : 1;
 	guint interrupted : 1;
 	guint device_locked : 1;
-	guint passive_mode : 1;
-	guint holding_event_source_id;
+	guint passive : 1;
 };
 
-static void speak(JammoMentor* mentor, const gchar* speech, gboolean highlight, gfloat offset_x, gfloat offset_y, JammoMentorSpokenCallback callback, gpointer user_data);
+static void speak(JammoMentor* mentor, const gchar* speech, gboolean highlight, gfloat offset_x, gfloat offset_y, guint duration, JammoMentorSpokenCallback callback, gpointer user_data);
 static void set_idle_timeout(JammoMentor* mentor, gboolean activate);
 static void on_mce_tklock_mode_sig(DBusGProxy* proxy, const gchar* mode, gpointer user_data);
 
@@ -113,25 +115,37 @@ void jammo_mentor_set_active_scale(JammoMentor* mentor, gfloat scale) {
 void jammo_mentor_speak(JammoMentor* mentor, const gchar* speech) {
 	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
 
-	speak(mentor, speech, FALSE, 0.0, 0.0, NULL, NULL);
+	speak(mentor, speech, FALSE, 0.0, 0.0, DEFAULT_DURATION, NULL, NULL);
 }
 
 void jammo_mentor_speak_with_callback(JammoMentor* mentor, const gchar* speech, JammoMentorSpokenCallback callback, gpointer user_data) {
 	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
 
-	speak(mentor, speech, FALSE, 0.0, 0.0, callback, user_data);
+	speak(mentor, speech, FALSE, 0.0, 0.0, DEFAULT_DURATION, callback, user_data);
 }
 
 void jammo_mentor_speak_and_highlight(JammoMentor* mentor, const gchar* speech, gfloat offset_x, gfloat offset_y) {
 	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
 
-	speak(mentor, speech, TRUE, offset_x, offset_y, NULL, NULL);
+	speak(mentor, speech, TRUE, offset_x, offset_y, DEFAULT_DURATION, NULL, NULL);
 }
 
 void jammo_mentor_speak_and_highlight_with_callback(JammoMentor* mentor, const gchar* speech, gfloat offset_x, gfloat offset_y, JammoMentorSpokenCallback callback, gpointer user_data) {
 	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
 
-	speak(mentor, speech, TRUE, offset_x, offset_y, callback, user_data);
+	speak(mentor, speech, TRUE, offset_x, offset_y, DEFAULT_DURATION, callback, user_data);
+}
+
+void jammo_mentor_highlight(JammoMentor* mentor, gfloat offset_x, gfloat offset_y, guint duration) {
+	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
+
+	speak(mentor, NULL, TRUE, offset_x, offset_y, duration, NULL, NULL);
+}
+
+void jammo_mentor_highlight_with_callback(JammoMentor* mentor, gfloat offset_x, gfloat offset_y, guint duration, JammoMentorSpokenCallback callback, gpointer user_data) {
+	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
+
+	speak(mentor, NULL, TRUE, offset_x, offset_y, duration, callback, user_data);
 }
 
 void jammo_mentor_speak_once(JammoMentor* mentor, const gchar* speech) {
@@ -139,7 +153,7 @@ void jammo_mentor_speak_once(JammoMentor* mentor, const gchar* speech) {
 
 	if (!g_list_find_custom(mentor->priv->spoken_speeches, speech, (GCompareFunc)g_strcmp0)) {
 		mentor->priv->spoken_speeches = g_list_prepend(mentor->priv->spoken_speeches, g_strdup(speech));
-		speak(mentor, speech, FALSE, 0.0, 0.0, NULL, NULL);
+		speak(mentor, speech, FALSE, 0.0, 0.0, DEFAULT_DURATION, NULL, NULL);
 	}
 }
 
@@ -148,7 +162,7 @@ void jammo_mentor_speak_once_with_callback(JammoMentor* mentor, const gchar* spe
 
 	if (!g_list_find_custom(mentor->priv->spoken_speeches, speech, (GCompareFunc)g_strcmp0)) {
 		mentor->priv->spoken_speeches = g_list_prepend(mentor->priv->spoken_speeches, g_strdup(speech));
-		speak(mentor, speech, FALSE, 0.0, 0.0, callback, user_data);
+		speak(mentor, speech, FALSE, 0.0, 0.0, DEFAULT_DURATION, callback, user_data);
 	}
 }
 
@@ -157,7 +171,7 @@ void jammo_mentor_speak_and_highlight_once(JammoMentor* mentor, const gchar* spe
 
 	if (!g_list_find_custom(mentor->priv->spoken_speeches, speech, (GCompareFunc)g_strcmp0)) {
 		mentor->priv->spoken_speeches = g_list_prepend(mentor->priv->spoken_speeches, g_strdup(speech));
-		speak(mentor, speech, TRUE, offset_x, offset_y, NULL, NULL);
+		speak(mentor, speech, TRUE, offset_x, offset_y, DEFAULT_DURATION, NULL, NULL);
 	}
 }
 
@@ -166,7 +180,7 @@ void jammo_mentor_speak_and_highlight_once_with_callback(JammoMentor* mentor, co
 
 	if (!g_list_find_custom(mentor->priv->spoken_speeches, speech, (GCompareFunc)g_strcmp0)) {
 		mentor->priv->spoken_speeches = g_list_prepend(mentor->priv->spoken_speeches, g_strdup(speech));
-		speak(mentor, speech, TRUE, offset_x, offset_y, callback, user_data);
+		speak(mentor, speech, TRUE, offset_x, offset_y, DEFAULT_DURATION, callback, user_data);
 	}
 }
 
@@ -235,28 +249,30 @@ void jammo_mentor_set_language(JammoMentor* mentor, const gchar* language) {
 	mentor->priv->language = g_strdup(language);
 }
 
+gboolean jammo_mentor_get_passive(JammoMentor* mentor){
+	g_return_val_if_fail(JAMMO_IS_MENTOR(mentor), FALSE);
+
+	return mentor->priv->passive;
+}
+
 void jammo_mentor_set_passive(JammoMentor* mentor, gboolean passive){
 	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
 
-	mentor->priv->passive_mode=passive;
-	if (passive) {
-		cem_add_to_log("Mentor goes to passive mode",J_LOG_DEBUG);
-		mentor->priv->passive_mode=1;
-		clutter_actor_set_opacity (CLUTTER_ACTOR(mentor), 60);
-		//store current idle_timeout
-		mentor->priv->default_idle_timeout=jammo_mentor_get_idle_timeout(mentor);
-		g_object_set (mentor,"idle-timeout", G_MAXULONG,NULL);
-	}
-	else {
-		cem_add_to_log("Mentor goes to active mode",J_LOG_DEBUG);
-		mentor->priv->passive_mode=0;
-		clutter_actor_set_opacity (CLUTTER_ACTOR(mentor), 255);
-		//return stored idle_timeout
-		jammo_mentor_set_idle_timeout(mentor,mentor->priv->default_idle_timeout);
+	if (mentor->priv->passive != passive) {
+		mentor->priv->passive = passive;
+		
+		if (passive) {
+			cem_add_to_log("Mentor goes to passive mode", J_LOG_DEBUG);
+
+			clutter_actor_set_opacity(CLUTTER_ACTOR(mentor), 60);
+		} else {
+			cem_add_to_log("Mentor goes to active mode", J_LOG_DEBUG);
+
+			clutter_actor_set_opacity(CLUTTER_ACTOR(mentor), 255);
+		}
 	}
 }
 
-
 gboolean jammo_mentor_get_device_locked(JammoMentor* mentor) {
 	g_return_val_if_fail(JAMMO_IS_MENTOR(mentor), FALSE);
 
@@ -276,13 +292,29 @@ static gboolean jammo_mentor_clicked(TangleButton* button) {
 	if (mentor->priv->active_sample) {
 		mentor->priv->interrupted = TRUE;
 		jammo_sample_stop(mentor->priv->active_sample);
+	} else if (mentor->priv->active_animation) {
+		mentor->priv->interrupted = TRUE;
+		clutter_animation_completed(mentor->priv->active_animation);
 	} else if (mentor->priv->idle_speech) {
-		speak(mentor, mentor->priv->idle_speech, FALSE, 0.0, 0.0, mentor->priv->idle_speech_spoken_callback, mentor->priv->idle_speech_spoken_user_data);
+		speak(mentor, mentor->priv->idle_speech, FALSE, 0.0, 0.0, DEFAULT_DURATION, mentor->priv->idle_speech_spoken_callback, mentor->priv->idle_speech_spoken_user_data);
 	}
 
 	return FALSE;
 }
 
+static gboolean jammo_mentor_held(TangleButton* button) {
+	JammoMentor* mentor;
+	
+	mentor = JAMMO_MENTOR(button);
+
+	cem_add_to_log("Mentor tap-and-hold",J_LOG_DEBUG);
+	jammo_mentor_shut_up(mentor);
+
+	jammo_mentor_set_passive(mentor, !mentor->priv->passive);
+
+	return FALSE;
+}
+
 static void jammo_mentor_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
 	JammoMentor* mentor;
 	
@@ -301,6 +333,9 @@ static void jammo_mentor_set_property(GObject* object, guint prop_id, const GVal
 		case PROP_IDLE_TIMEOUT:
 			jammo_mentor_set_idle_timeout(mentor, g_value_get_ulong(value));
 			break;
+		case PROP_PASSIVE:
+			jammo_mentor_set_passive(mentor, g_value_get_boolean(value));
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 			break;
@@ -325,6 +360,9 @@ static void jammo_mentor_get_property(GObject* object, guint prop_id, GValue* va
 		case PROP_IDLE_TIMEOUT:
 			g_value_set_ulong(value, mentor->priv->idle_timeout);
 			break;
+		case PROP_PASSIVE:
+			g_value_set_boolean(value, mentor->priv->passive);
+			break;
 		case PROP_DEVICE_LOCKED:
 			g_value_set_boolean(value, mentor->priv->device_locked);
 			break;
@@ -365,45 +403,10 @@ static void jammo_mentor_dispose(GObject* object) {
 	G_OBJECT_CLASS(jammo_mentor_parent_class)->dispose(object);
 }
 
-
-static gboolean tap_and_hold_function(gpointer user_data) {
-	JammoMentor* mentor;
-	mentor = JAMMO_MENTOR(user_data);
-
-	mentor->priv->holding_event_source_id = 0;
-
-	cem_add_to_log("Mentor tap-and-hold",J_LOG_DEBUG);
-	jammo_mentor_shut_up(mentor);
-
-	jammo_mentor_set_passive(mentor,!mentor->priv->passive_mode);
-
-	return FALSE;
-
-}
-
-static gboolean jammo_mentor_pressed (ClutterActor *actor, ClutterButtonEvent *event) {
-	JAMMO_MENTOR(actor)->priv->holding_event_source_id = g_timeout_add(3500, tap_and_hold_function, actor);
-	return TRUE;
-}
-
-
-static gboolean jammo_mentor_released (ClutterActor *actor, ClutterButtonEvent *event) {
-	if (JAMMO_MENTOR(actor)->priv->holding_event_source_id) {
-		g_source_remove(JAMMO_MENTOR(actor)->priv->holding_event_source_id);
-		JAMMO_MENTOR(actor)->priv->holding_event_source_id = 0;
-
-		//If tap_and_hold_function is triggered, we do not want call this:
-		jammo_mentor_clicked(TANGLE_BUTTON(actor));
-	}
-
-	return TRUE;
-}
-
 static void jammo_mentor_class_init(JammoMentorClass* mentor_class) {
 	GObjectClass* gobject_class = G_OBJECT_CLASS(mentor_class);
 	ClutterActorClass* clutter_actor_class = CLUTTER_ACTOR_CLASS(mentor_class);
-	//TangleButtonClass* button_class = TANGLE_BUTTON_CLASS(mentor_class);
-	//button_class->clicked = jammo_mentor_clicked;
+	TangleButtonClass* button_class = TANGLE_BUTTON_CLASS(mentor_class);
 
 	gobject_class->finalize = jammo_mentor_finalize;
 	gobject_class->dispose = jammo_mentor_dispose;
@@ -412,8 +415,9 @@ static void jammo_mentor_class_init(JammoMentorClass* mentor_class) {
 
 	clutter_actor_class->show = jammo_mentor_show;
 	clutter_actor_class->hide = jammo_mentor_hide;
-	clutter_actor_class->button_release_event = jammo_mentor_released;
-	clutter_actor_class->button_press_event = jammo_mentor_pressed;
+
+	button_class->clicked = jammo_mentor_clicked;
+	button_class->held = jammo_mentor_held;
 
 	/**
 	 * JammoMentor:standby-scale:
@@ -460,6 +464,19 @@ static void jammo_mentor_class_init(JammoMentorClass* mentor_class) {
 	                                                   "The time in seconds after the mentor will speak if an user has been idle.",
 	                                                   0, G_MAXULONG, 0,
 	                                                   G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_CONSTRUCT));
+	/**
+	 * JammoMentor:passive:
+	 *
+	 * Whether the mentor is passive.
+	 *
+	 * Passive mentor does not respond or speak after idle timeout.
+	 */
+	g_object_class_install_property(gobject_class, PROP_PASSIVE,
+	                                g_param_spec_boolean("passive",
+	                                                     "Passive",
+	                                                     "Whether the mentor is passive",
+	                                                     FALSE,
+	                                                     G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 	/**
 	 * JammoMentor:device-locked:
 	 *
@@ -483,9 +500,10 @@ static void jammo_mentor_init(JammoMentor* mentor) {
 	DBusGConnection* connection;
 
 	mentor->priv = G_TYPE_INSTANCE_GET_PRIVATE(mentor, JAMMO_TYPE_MENTOR, JammoMentorPrivate);
-	mentor->priv->passive_mode=0;
 	mentors = g_list_append(mentors, mentor);
 	
+	g_object_set(mentor, "hold-timeout", 1500, NULL);
+	
 	if ((connection = dbus_g_bus_get(DBUS_BUS_SYSTEM, NULL))) {
 		mentor->priv->mce_proxy = dbus_g_proxy_new_for_name(connection, MCE_SERVICE, MCE_SIGNAL_PATH, MCE_SIGNAL_IF);
 		dbus_g_proxy_add_signal(mentor->priv->mce_proxy, MCE_TKLOCK_MODE_SIG, G_TYPE_STRING, G_TYPE_INVALID);
@@ -549,8 +567,7 @@ static void on_sample_stopped(JammoSample* sample, gpointer user_data) {
 	if (next_speech && !mentor->priv->interrupted) {
 		real_speak(mentor, next_speech, callback, speech, data);
 	} else {
-
-		tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, 1000, "squint-x", 0.0, "squint-y", 0.0, "scale-x", mentor->priv->standby_scale, "scale-y", mentor->priv->standby_scale, NULL);
+		tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, DEFAULT_DURATION, "squint-x", 0.0, "squint-y", 0.0, "scale-x", mentor->priv->standby_scale, "scale-y", mentor->priv->standby_scale, NULL);
 
 		set_idle_timeout(mentor, TRUE);
 
@@ -564,6 +581,28 @@ static void on_sample_stopped(JammoSample* sample, gpointer user_data) {
 	}
 }
 
+static void on_animation_completed(ClutterAnimation* animation, gpointer user_data) {
+	TangleVault* vault;
+	JammoMentor* mentor;
+	JammoMentorSpokenCallback callback;
+	gpointer data;
+
+	vault = TANGLE_VAULT(user_data);
+	tangle_vault_get(vault, 3, JAMMO_TYPE_MENTOR, &mentor, G_TYPE_POINTER, &callback, G_TYPE_POINTER, &data);
+
+	tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, DEFAULT_DURATION, "squint-x", 0.0, "squint-y", 0.0, "scale-x", mentor->priv->standby_scale, "scale-y", mentor->priv->standby_scale, NULL);
+
+	set_idle_timeout(mentor, TRUE);
+
+	if (callback) {
+		callback(mentor, NULL, mentor->priv->interrupted, data);
+	}
+
+	mentor->priv->interrupted = FALSE;
+
+	/* TODO: g_free(speech); ? */
+}
+
 #define WHITE_SPACES " \t\n\r"
 
 static void real_speak(JammoMentor* mentor, const gchar* next_speech, JammoMentorSpokenCallback callback, const gchar* speech, gpointer user_data) {
@@ -605,27 +644,36 @@ static void real_speak(JammoMentor* mentor, const gchar* next_speech, JammoMento
 	jammo_sample_play(mentor->priv->active_sample);
 }
 
-static void speak(JammoMentor* mentor, const gchar* speech, gboolean highlight, gfloat offset_x, gfloat offset_y, JammoMentorSpokenCallback callback, gpointer user_data) {	
+static void speak(JammoMentor* mentor, const gchar* speech, gboolean highlight, gfloat offset_x, gfloat offset_y, guint duration, JammoMentorSpokenCallback callback, gpointer user_data) {
+	ClutterAnimation* animation;
+	TangleVault* vault;
 
-	set_idle_timeout(mentor, FALSE);
-	tangle_actor_show(TANGLE_ACTOR(mentor));
-
-	if (mentor->priv->passive_mode) {
-		cem_add_to_log(" Mentor in passive mode, skip",J_LOG_DEBUG);
+	if (mentor->priv->passive) {
+		cem_add_to_log(" Mentor in passive mode, skip", J_LOG_DEBUG);
+		
 		if (callback) {
 			callback(mentor, speech, TRUE, user_data);
-			}
-	return;
+		}
+	} else {
+		set_idle_timeout(mentor, FALSE);
+		tangle_actor_show(TANGLE_ACTOR(mentor));
+
+		if (mentor->priv->active_sample) {
+			jammo_sample_stop(mentor->priv->active_sample);
+		}
+
+		animation = tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, duration, "squint-x", offset_x, "squint-y", offset_y, "scale-x", mentor->priv->active_scale, "scale-y", mentor->priv->active_scale, NULL);
+
+		if (speech) {
+			real_speak(mentor, speech, callback, speech, user_data);
+		} else {
+			vault = tangle_vault_new(3, JAMMO_TYPE_MENTOR, mentor, G_TYPE_POINTER, callback, G_TYPE_POINTER, user_data);
+			tangle_signal_connect_vault(animation, "completed", G_CALLBACK(on_animation_completed), vault);
+
+			mentor->priv->active_animation = animation;
+			g_object_add_weak_pointer(G_OBJECT(mentor->priv->active_animation), (gpointer*)&mentor->priv->active_animation);
+		}
 	}
-
-
-	if (mentor->priv->active_sample) {
-		jammo_sample_stop(mentor->priv->active_sample);
-	}
-
-	real_speak(mentor, speech, callback, speech, user_data);
-	
-	tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, 1000, "squint-x", offset_x, "squint-y", offset_y, "scale-x", mentor->priv->active_scale, "scale-y", mentor->priv->active_scale, NULL);
 }
 
 static gboolean on_stage_captured_event(ClutterActor* actor, ClutterEvent* event, gpointer user_data) {
@@ -645,10 +693,10 @@ static gboolean on_timeout(gpointer user_data) {
 	mentor = JAMMO_MENTOR(user_data);
 	
 	elapsed_time = time(NULL) - mentor->priv->last_activity_time;
-	if (elapsed_time >= mentor->priv->idle_timeout) {
+	if (!mentor->priv->passive && elapsed_time >= mentor->priv->idle_timeout) {
 		mentor->priv->timeout_event_source_id = 0;
 		mentor->priv->idle_speech_spoken = TRUE;
-		speak(mentor, mentor->priv->idle_speech, FALSE, 0.0, 0.0, mentor->priv->idle_speech_spoken_callback, mentor->priv->idle_speech_spoken_user_data);
+		speak(mentor, mentor->priv->idle_speech, FALSE, 0.0, 0.0, DEFAULT_DURATION, mentor->priv->idle_speech_spoken_callback, mentor->priv->idle_speech_spoken_user_data);
 	} else {
 		mentor->priv->timeout_event_source_id = g_timeout_add((mentor->priv->idle_timeout - elapsed_time) * 1000, on_timeout, mentor);
 	}
