@@ -45,6 +45,8 @@ void jammo_mentor_speak(JammoMentor* mentor, const gchar* speech);
 void jammo_mentor_speak_with_callback(JammoMentor* mentor, const gchar* speech, JammoMentorSpokenCallback callback, gpointer user_data);
 void jammo_mentor_speak_and_highlight(JammoMentor* mentor, const gchar* speech, gfloat offset_x, gfloat offset_y);
 void jammo_mentor_speak_and_highlight_with_callback(JammoMentor* mentor, const gchar* speech, gfloat offset_x, gfloat offset_y, JammoMentorSpokenCallback callback, gpointer user_data);
+void jammo_mentor_highlight(JammoMentor* mentor, gfloat offset_x, gfloat offset_y, guint duration);
+void jammo_mentor_highlight_with_callback(JammoMentor* mentor, gfloat offset_x, gfloat offset_y, guint duration, JammoMentorSpokenCallback callback, gpointer user_data);
 void jammo_mentor_speak_once(JammoMentor* mentor, const gchar* speech);
 void jammo_mentor_speak_once_with_callback(JammoMentor* mentor, const gchar* speech, JammoMentorSpokenCallback callback, gpointer user_data);
 void jammo_mentor_speak_and_highlight_once(JammoMentor* mentor, const gchar* speech, gfloat offset_x, gfloat offset_y);
@@ -56,8 +58,9 @@ void jammo_mentor_set_idle_speech_with_callback(JammoMentor* mentor, const gchar
 gulong jammo_mentor_get_idle_timeout(JammoMentor* mentor);
 void jammo_mentor_set_idle_timeout(JammoMentor* mentor, gulong milliseconds);
 const gchar* jammo_mentor_get_language(JammoMentor* mentor);
-void jammo_mentor_set_passive(JammoMentor* mentor, gboolean mode);
 void jammo_mentor_set_language(JammoMentor* mentor, const gchar* language);
+gboolean jammo_mentor_get_passive(JammoMentor* mentor);
+void jammo_mentor_set_passive(JammoMentor* mentor, gboolean passive);
 gboolean jammo_mentor_get_device_locked(JammoMentor* mentor);
 
 JammoMentor* jammo_mentor_get_default(void);
