@@ -45,6 +45,7 @@ struct _JammoSampleButtonPrivate {
 	ClutterAction* drag_action;
 	
 	guint dragging : 1;
+	gboolean waltz;
 };
 
 static const GEnumValue sample_type_values[] = {
@@ -97,7 +98,12 @@ ClutterActor* jammo_sample_button_new_with_type_from_files(JammoSampleType sampl
 
 ClutterActor* jammo_sample_button_new_from_existing(JammoSampleButton* sample_button) {
 
-	return CLUTTER_ACTOR(g_object_new(JAMMO_TYPE_SAMPLE_BUTTON, "image-filename", sample_button->priv->image_filename, "sample", sample_button->priv->sample, "sample-type", sample_button->priv->sample_type, "loop-id", sample_button->priv->loop_id, NULL));
+	ClutterActor* new_sample_button = CLUTTER_ACTOR(g_object_new(JAMMO_TYPE_SAMPLE_BUTTON, "image-filename", sample_button->priv->image_filename, "sample", sample_button->priv->sample, "sample-type", sample_button->priv->sample_type, "loop-id", sample_button->priv->loop_id, NULL));
+
+	JAMMO_SAMPLE_BUTTON(new_sample_button)->priv->waltz = sample_button->priv->waltz;
+	jammo_sample_button_set_text(JAMMO_SAMPLE_BUTTON(new_sample_button),jammo_sample_button_get_text(sample_button));
+
+	return new_sample_button;
 }
 
 const gchar* jammo_sample_button_get_image_filename(JammoSampleButton* sample_button) {
@@ -211,6 +217,14 @@ void jammo_sample_button_set_sample_type(JammoSampleButton* sample_button, Jammo
 	}
 }
 
+gboolean jammo_sample_button_is_waltz(JammoSampleButton* sample_button) {
+ return sample_button->priv->waltz;
+}
+
+void jammo_sample_button_set_waltz(JammoSampleButton* sample_button, gboolean state) {
+ sample_button->priv->waltz=state;
+}
+
 const gchar* jammo_sample_button_get_text(JammoSampleButton* sample_button) {
 	const gchar* text = NULL;
 	ClutterActor* actor;
@@ -269,6 +283,7 @@ static void jammo_sample_button_constructed(GObject* object) {
 	tangle_widget_set_prefer_background_size(TANGLE_WIDGET(object), TRUE);
 	g_signal_connect(object, "clicked", G_CALLBACK(on_clicked), NULL);
 
+	sample_button->priv->waltz=FALSE;
 	G_OBJECT_CLASS(jammo_sample_button_parent_class)->constructed(object);
 }
 
