@@ -18,7 +18,7 @@ void make_reactive_all_knots(ClutterActor **matrix, gint size, gboolean make_rea
 /**
  * Matrix is a handle for all knot points.
  */
-void create_all_knots(ClutterActor *parent, ClutterActor **matrix, gpointer on_spot_enter, gpointer verify_path) {
+void create_all_knots(ClutterActor *parent, ClutterActor **matrix, GCallback on_spot_enter, GCallback verify_path) {
 	int i, j, index = 1;
 	for (i = 30; i < 370; i += 160) {
 		for (j = 30; j < 370; j += 160) {
