@@ -36,7 +36,9 @@ ClutterActor* loginname_text = NULL;
 /**
  *
  */
-gboolean verify_path(ClutterRectangle *rect, ClutterEvent *event, ClutterActor *container, gpointer data) {
+static gboolean verify_path(ClutterActor* actor, ClutterEvent* event, gpointer data) {
+
+	ClutterActor* container = CLUTTER_ACTOR(data);
 	int *pp;
 	int *p_arr = g_malloc(40 * sizeof(int));
 	int i;
@@ -60,7 +62,7 @@ gboolean verify_path(ClutterRectangle *rect, ClutterEvent *event, ClutterActor *
 
 	//New validation I keep the old one for now
 	//make_reactive_all_knots(mySpot, NUM_OF_SPOTS, TRUE);
-	pg_validate_passwd(container, test_pass, is_reset_passwd);
+	//
 	/* if (check==1)
 	 {
 	 g_print("\nWelcome :)\n");
@@ -78,6 +80,9 @@ gboolean verify_path(ClutterRectangle *rect, ClutterEvent *event, ClutterActor *
 	//check=0;
 	g_free(p_arr);
 	i_plus = 0;
+
+	pg_validate_passwd(container, test_pass, is_reset_passwd);
+	cem_add_to_log("login_screen.c: verify_path will return TRUE", J_LOG_DEBUG);
 	return TRUE;
 	//set_knots_buff(); //INITIALIZE THE BUFFER AGAIN
 }
@@ -102,25 +107,14 @@ gboolean on_box_enter(ClutterActor *box, ClutterEvent *event,
 	gfloat y = 0;
 	clutter_event_get_coords(event, &x, &y);
 	set_xy_in_xml(x, y);
-	//int emblem_id;
-	//emblem_id = clutter_actor_get_gid(emblem);
 
-	/*
-	 fill_knots_buff(emblem_id,2,i_plus);
-	 int *pp;
-	 int p;
-	 pp = get_knot_buff_a();
-	 p =pp[0];
-	 i_plus=i_plus+1;
-	 g_print(" %d,",emblem_id);
-	 g_signal_connect (emblem, "button-release-event", G_CALLBACK (verify_path), display_error_actor);
-	 */
 	return FALSE;
 }
 
-static gboolean on_spot_enter(ClutterActor *box, ClutterEvent *event, ClutterActor *container, gpointer data) {
+static gboolean on_spot_enter(ClutterActor *box, ClutterEvent *event, gpointer data) {
 	//NO OVERFLOW
 
+	ClutterActor* container = CLUTTER_ACTOR(data);
 	ClutterModifierType etype = clutter_event_get_state(event);
 	g_print("%d\n", etype);
 
@@ -145,8 +139,8 @@ static gboolean on_spot_enter(ClutterActor *box, ClutterEvent *event, ClutterAct
 	return FALSE;
 }
 
-static gboolean on_box_leave(ClutterActor *box, ClutterEvent *event,
-		ClutterActor *emblem) {
+static gboolean on_box_leave(ClutterActor *box, ClutterEvent *event, gpointer data) {
+	ClutterActor* emblem = CLUTTER_ACTOR(data);
 	clutter_actor_set_opacity(emblem, 0);
 	/*
 	 clutter_actor_animate(emblem, CLUTTER_EASE_IN_SINE, 200,
@@ -238,7 +232,7 @@ void login_screen() {
 		}
 	}
 
-	create_all_knots(ls_point_container, mySpot, on_spot_enter, verify_path);
+	create_all_knots(ls_point_container, mySpot, G_CALLBACK(on_spot_enter), G_CALLBACK(verify_path));
 
 	pg_set_select_option_screen(stage);
 	
