@@ -4,7 +4,7 @@
 
 
 int *get_user_passwd();
-gboolean pg_validate_passwd (ClutterActor *stage, gchar *password,int is_new);
+void pg_validate_passwd (ClutterActor *stage, gchar *password,int is_new);
 gboolean pg_save_passwd (gchar *passwd);
 gchar *pg_read_passwd_from_file();
 gchar *pg_convert_points_to_string(int *array, int array_len);
