@@ -164,7 +164,7 @@ guint32 ProfileManager::GetId()
 	return iUser;
 }
 
-guint ProfileManager::loadEncryptedProfile(gchar* _username)
+guint ProfileManager::loadEncryptedProfile(const gchar* _username)
 {
 	if(iStorageAgent->isProfileLoaded())
 	{
@@ -239,7 +239,7 @@ gboolean ProfileManager::saveEncryptedProfile()
 		}
 }
 
-gboolean ProfileManager::changeLoadedUser(gchar* _username)
+gboolean ProfileManager::changeLoadedUser(const gchar* _username)
 {
 	// clear previous user data
 	iStorageAgent->clearEncryptedData();
@@ -248,6 +248,13 @@ gboolean ProfileManager::changeLoadedUser(gchar* _username)
 	return loadEncryptedProfile(_username);
 }
 
+void ProfileManager::clearLoadedUser()
+{
+	// clear previous user data
+	iStorageAgent->clearEncryptedData();
+	iStorageAgent->clearDetails();
+}
+
 gboolean ProfileManager::deserializeProfile(gchar* _profile)
 {
 	gboolean rval = iStorageAgent->deserializeProfile(_profile);
@@ -360,7 +367,7 @@ void log_wrap(char* msg, int info)
 ////////////////////////////////////////////////////////*/
 
 // New manager object
-ProfileManager* profilemanager_new_manager()
+ProfileManager* profilemanager_get_manager()
 {
 	return ProfileManager::GetInstance();
 }
@@ -374,100 +381,100 @@ void profilemanager_delete_manager(ProfileManager* _aManager)
 // Login to manager (no auth checking yet)
 gboolean profilemanager_login(ProfileManager* _aManager, guint32 _userId)
 {
-	if(_aManager == NULL) return FALSE;
-	return _aManager->Login(_userId);
+	//if(_aManager == NULL) return FALSE;
+	return profilemanager_get_manager()->Login(_userId);
 }
 
 // Logout from manager
 gboolean profilemanager_logout(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return FALSE;
-	return _aManager->Logout();
+	//if(_aManager == NULL) return FALSE;
+	return profilemanager_get_manager()->Logout();
 }
 
 // View one information
 const gchar* profilemanager_view_info(ProfileManager* _aManager, gchar* _parameter)
 {
-	if(_aManager == NULL) return NULL;
+	//if(_aManager == NULL) return NULL;
 	
 	string param = string(_parameter);
-	return (_aManager->ViewDetail(param)).c_str();
+	return (profilemanager_get_manager()->ViewDetail(param)).c_str();
 }
 
 // Edit own info
 gboolean profilemanager_edit_info(ProfileManager* _aManager, gchar* _parameter, gchar* _value)
 {
-	if(_aManager == NULL) return FALSE;
+	//if(_aManager == NULL) return FALSE;
 	string param = string(_parameter);
 	string value = string(_value);
-	return _aManager->EditDetails(param,value);
+	return profilemanager_get_manager()->EditDetails(param,value);
 }
 
 guint32 profilemanager_get_userid(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return 0;
-	return _aManager->GetId();
+	//if(_aManager == NULL) return 0;
+	return profilemanager_get_manager()->GetId();
 }
 
 // Get own username
 const gchar* profilemanager_get_username(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return NULL;
+	//if(_aManager == NULL) return NULL;
 	
 	string param = string(PROF_PARAM_USERNAME);
-	return (_aManager->ViewDetail(param)).c_str();
+	return (profilemanager_get_manager()->ViewDetail(param)).c_str();
 }
 
 // Get first name
 const gchar* profilemanager_get_firstname(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return NULL;
+	//if(_aManager == NULL) return NULL;
 	
 	string param = string(PROF_PARAM_FIRSTNAME);
-	return (_aManager->ViewDetail(param)).c_str();
+	return (profilemanager_get_manager()->ViewDetail(param)).c_str();
 }
 
 // Get last name
 const gchar* profilemanager_get_lastname(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return NULL;
+	//if(_aManager == NULL) return NULL;
 	
 	string param = string(PROF_PARAM_LASTNAME);
-	return (_aManager->ViewDetail(param)).c_str();
+	return (profilemanager_get_manager()->ViewDetail(param)).c_str();
 }
 
 // Get age
 guint16 profilemanager_get_age(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return 0;
+	//if(_aManager == NULL) return 0;
 	
 	string param = string(PROF_PARAM_AGE);
-	return atoi((_aManager->ViewDetail(param)).c_str());
+	return atoi((profilemanager_get_manager()->ViewDetail(param)).c_str());
 }
 
 guint32 profilemanager_get_points(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return 0;
+	//if(_aManager == NULL) return 0;
 	
 	string param = string(PROF_PARAM_POINTS);
-	return (guint32)strtoul((_aManager->ViewDetail(param)).c_str(),NULL,10);
+	return (guint32)strtoul((profilemanager_get_manager()->ViewDetail(param)).c_str(),NULL,10);
 }
 
 /* Get avatar id */
 guint32 profilemanager_get_avatarid(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return PROF_DEFAULT_AVATARID;
+	//if(_aManager == NULL) return PROF_DEFAULT_AVATARID;
 	
 	string param = string(PROF_PARAM_AVATARID);
-	return (guint32)strtoul((_aManager->ViewDetail(param)).c_str(),NULL,10);
+	return (guint32)strtoul((profilemanager_get_manager()->ViewDetail(param)).c_str(),NULL,10);
 }
 
 guint8 profilemanager_get_profile_type(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return 0;
+	//if(_aManager == NULL) return 0;
 	
 	string param = string(PROF_PARAM_TYPE);
-	guint8 type = (guint8)atoi(_aManager->ViewDetail(param).c_str());
+	guint8 type = (guint8)atoi(profilemanager_get_manager()->ViewDetail(param).c_str());
 	
 	// Currently only 2 types of profiles
 	if(type < PROF_TYPE_LOCAL || type > PROF_TYPE_REMOTE) return 0;
@@ -476,41 +483,41 @@ guint8 profilemanager_get_profile_type(ProfileManager* _aManager)
 
 guint8 profilemanager_get_profile_version(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return 0;
+	//if(_aManager == NULL) return 0;
 	
-	return _aManager->getProfileVersion();
+	return profilemanager_get_manager()->getProfileVersion();
 }
 
 gboolean profilemanager_set_username(ProfileManager* _aManager, gchar* _value)
 {
-	if(_aManager == NULL) return FALSE;
+	//if(_aManager == NULL) return FALSE;
 	
 	string param = string(PROF_PARAM_USERNAME);
 	string value = string(_value);
-	return _aManager->EditDetails(param,value);
+	return profilemanager_get_manager()->EditDetails(param,value);
 }
 
 gboolean profilemanager_set_firstname(ProfileManager* _aManager, gchar* _value)
 {
-	if(_aManager == NULL) return FALSE;
+	//if(_aManager == NULL) return FALSE;
 	
 	string param = string(PROF_PARAM_FIRSTNAME);
 	string value = string(_value);
-	return _aManager->EditDetails(param,value);
+	return profilemanager_get_manager()->EditDetails(param,value);
 }
 
 gboolean profilemanager_set_lastname(ProfileManager* _aManager, gchar* _value)
 {
-	if(_aManager == NULL) return FALSE;
+	//if(_aManager == NULL) return FALSE;
 	
 	string param = string(PROF_PARAM_LASTNAME);
 	string value = string(_value);
-	return _aManager->EditDetails(param,value);
+	return profilemanager_get_manager()->EditDetails(param,value);
 }
 
 gboolean profilemanager_set_age(ProfileManager* _aManager, guint16 _value)
 {
-	if(_aManager == NULL) return FALSE;
+	//if(_aManager == NULL) return FALSE;
 	
 	stringstream strvalue;
 	string param = string(PROF_PARAM_AGE);
@@ -520,12 +527,12 @@ gboolean profilemanager_set_age(ProfileManager* _aManager, guint16 _value)
 	strvalue << _value;
 	string value = strvalue.str();
 	
-	return _aManager->EditDetails(param,value);
+	return profilemanager_get_manager()->EditDetails(param,value);
 }
 
 gboolean profilemanager_set_avatarid(ProfileManager* _aManager, guint32 _value)
 {
-	if(_aManager == NULL) return FALSE;
+	//if(_aManager == NULL) return FALSE;
 	
 	string param = string(PROF_PARAM_AVATARID);
 	
@@ -534,15 +541,15 @@ gboolean profilemanager_set_avatarid(ProfileManager* _aManager, guint32 _value)
 	
 	string value = strvalue.str();
 	
-	return _aManager->EditDetails(param,value);
+	return profilemanager_get_manager()->EditDetails(param,value);
 }
 
 gboolean profilemanager_add_points(ProfileManager* _aManager, guint32 _value)
 {
-	if(_aManager == NULL) return FALSE;
+	//if(_aManager == NULL) return FALSE;
 	
 	string param = string(PROF_PARAM_POINTS);
-	guint32 points = (guint32)strtoul((_aManager->ViewDetail(param)).c_str(),NULL,10);
+	guint32 points = (guint32)strtoul((profilemanager_get_manager()->ViewDetail(param)).c_str(),NULL,10);
 	
 	points += _value;
 	
@@ -551,15 +558,15 @@ gboolean profilemanager_add_points(ProfileManager* _aManager, guint32 _value)
 	
 	string value = strvalue.str();
 	
-	return _aManager->EditDetails(param,value);
+	return profilemanager_get_manager()->EditDetails(param,value);
 }
 
 gboolean profilemanager_remove_points(ProfileManager* _aManager, guint32 _value)
 {
-	if(_aManager == NULL) return FALSE;
+	//if(_aManager == NULL) return FALSE;
 	
 	string param = string(PROF_PARAM_POINTS);
-	guint32 points = (guint32)strtoul((_aManager->ViewDetail(param)).c_str(),NULL,10);
+	guint32 points = (guint32)strtoul((profilemanager_get_manager()->ViewDetail(param)).c_str(),NULL,10);
 	
 	if((points - _value) < 0) points = 0;
 	else points = points - _value;
@@ -569,122 +576,127 @@ gboolean profilemanager_remove_points(ProfileManager* _aManager, guint32 _value)
 	
 	string value = strvalue.str();
 	
-	return _aManager->EditDetails(param,value);	
+	return profilemanager_get_manager()->EditDetails(param,value);	
 }
 
 void profilemanager_reset_points(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return;
+	//if(_aManager == NULL) return;
 	
 	string param = string(PROF_PARAM_POINTS);
 	string value = "0";
-	_aManager->EditDetails(param,value);
+	profilemanager_get_manager()->EditDetails(param,value);
 }
 
-guint profilemanager_storage_load_profile(ProfileManager* _aManager, gchar* _username)
+guint profilemanager_storage_load_profile(ProfileManager* _aManager, const gchar* _username)
 {
-	if(_aManager == NULL) return FALSE;
-	return _aManager->loadEncryptedProfile(_username);
+	//if(_aManager == NULL) return FALSE;
+	return profilemanager_get_manager()->loadEncryptedProfile(_username);
 }
 
 guint profilemanager_storage_reload_profile(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return FALSE;
-	return _aManager->reloadEncryptedProfile();
+	//if(_aManager == NULL) return FALSE;
+	return profilemanager_get_manager()->reloadEncryptedProfile();
 }
 
 gboolean profilemanager_storage_save_profile(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return FALSE;
-	return _aManager->saveEncryptedProfile();
+	//if(_aManager == NULL) return FALSE;
+	return profilemanager_get_manager()->saveEncryptedProfile();
 }
 
 gboolean profilemanager_storage_change_profile(ProfileManager* _aManager, gchar* _username)
 {
-	if(_aManager == NULL) return FALSE;
-	return _aManager->changeLoadedUser(_username);
+	//if(_aManager == NULL) return FALSE;
+	return profilemanager_get_manager()->changeLoadedUser(_username);
+}
+
+void profilemanager_storage_clear_profile(ProfileManager* _aManager)
+{
+	/*if(_aManager)*/ profilemanager_get_manager()->clearLoadedUser();
 }
 
 guchar* profilemanager_storage_get_password_salt(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return NULL;
-	return _aManager->getSalt();
+	//if(_aManager == NULL) return NULL;
+	return profilemanager_get_manager()->getSalt();
 }
 
 guchar* profilemanager_storage_get_password_hash(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return NULL;
-	return _aManager->getPasswordHash();
+	//if(_aManager == NULL) return NULL;
+	return profilemanager_get_manager()->getPasswordHash();
 }
 
 guchar* profilemanager_storage_get_profile_hash(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return NULL;
-	return _aManager->getProfileHash();
+	//if(_aManager == NULL) return NULL;
+	return profilemanager_get_manager()->getProfileHash();
 }
 
 guchar* profilemanager_storage_get_encrypted_profile(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return NULL;
-	return _aManager->getEncryptedProfile();
+	//if(_aManager == NULL) return NULL;
+	return profilemanager_get_manager()->getEncryptedProfile();
 }
 
 guint profilemanager_storage_get_encrypted_profile_size(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return 0;
-	return _aManager->getEncryptedProfileSize();
+	//if(_aManager == NULL) return 0;
+	return profilemanager_get_manager()->getEncryptedProfileSize();
 }
 
 gboolean profilemanager_storage_set_password_salt(ProfileManager* _aManager, guchar* _salt)
 {
-	if(_aManager == NULL) return FALSE;
-	return _aManager->setSalt(_salt);
+	//if(_aManager == NULL) return FALSE;
+	return profilemanager_get_manager()->setSalt(_salt);
 }
 
 gboolean profilemanager_storage_set_password_hash(ProfileManager* _aManager, guchar* _hash)
 {
-	if(_aManager == NULL) return FALSE;
-	return _aManager->setPasswordHash(_hash);
+	//if(_aManager == NULL) return FALSE;
+	return profilemanager_get_manager()->setPasswordHash(_hash);
 }
 
 gboolean profilemanager_storage_set_encrypted_profile(ProfileManager* _aManager, guchar* _profile_hash, guchar* _encrypted_profile, guint _e_profile_size)
 {
-	if(_aManager == NULL) return FALSE;
-	return _aManager->setEncryptedProfile(_profile_hash, _encrypted_profile, _e_profile_size);
+	//if(_aManager == NULL) return FALSE;
+	return profilemanager_get_manager()->setEncryptedProfile(_profile_hash, _encrypted_profile, _e_profile_size);
 }
 
 gboolean profilemanager_storage_deserialize_profile(ProfileManager* _aManager, guchar* _profile)
 {
-	if(_aManager == NULL) return FALSE;
-	return _aManager->deserializeProfile((gchar*)_profile);
+	//if(_aManager == NULL) return FALSE;
+	return profilemanager_get_manager()->deserializeProfile((gchar*)_profile);
 }
 
 gchar* profilemanager_storage_serialize_profile(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return NULL;
-	return _aManager->serializeProfile();
+	//if(_aManager == NULL) return NULL;
+	return profilemanager_get_manager()->serializeProfile();
 }
 
 gboolean profilemanager_set_authenticated(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return FALSE;
-	return _aManager->setAuthenticated();
+	//if(_aManager == NULL) return FALSE;
+	return profilemanager_get_manager()->setAuthenticated();
 }
 
 gboolean profilemanager_is_authenticated(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return FALSE;
-	return _aManager->isAuthenticated();
+	//if(_aManager == NULL) return FALSE;
+	return profilemanager_get_manager()->isAuthenticated();
 }
 gboolean profilemanager_is_saving_required(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return FALSE;
-	return _aManager->isSavingRequired();
+	//if(_aManager == NULL) return FALSE;
+	return profilemanager_get_manager()->isSavingRequired();
 }
 
 gchar* profilemanager_get_loaded_username(ProfileManager* _aManager)
 {
-	if(_aManager == NULL) return NULL;
-	return _aManager->getLoadedUsername();
+	//if(_aManager == NULL) return NULL;
+	return profilemanager_get_manager()->getLoadedUsername();
 }
 
