@@ -64,7 +64,7 @@ void gems_unset_teacher_profile_timeout_sid(gpointer param);
 void gems_increase_teacher_profile_request_counter();
 void gems_reset_teacher_profile_request_counter();
 guint gems_get_teacher_profile_request_count();
-void gems_set_login_username(gchar* username, gboolean forced);
+void gems_set_login_username(const gchar* username, gboolean forced);
 gchar* gems_get_login_username();
 void gems_clear_login_username();
 gboolean gems_login_username_forced();
