@@ -51,12 +51,13 @@ gboolean gems_profile_manager_set_password_pen_gesture(guint32 userId, gchar* us
 
 
 
-gint gems_profile_manager_authenticate_default_user(gchar* passworddata)
+gint gems_profile_manager_authenticate_default_user(const gchar* passworddata)
 {
+	profilemanager_storage_clear_profile(gems_get_profile_manager());
 	return gems_profile_manager_authenticate_user("defaultuser",passworddata);
 }
 
-gint gems_profile_manager_authenticate_user(gchar* username, gchar* passworddata)
+gint gems_profile_manager_authenticate_user(const gchar* username, const gchar* passworddata)
 {
 	guint passlength = 0;
 	guint proflength = 0;
@@ -65,12 +66,12 @@ gint gems_profile_manager_authenticate_user(gchar* username, gchar* passworddata
 	guchar* pwhash = NULL;
 	guchar* decrypted = NULL;
 	guchar* decprofhash = NULL;
-	ProfileManager* pm = gems_get_data()->pm;
+	ProfileManager* pm = gems_get_profile_manager();
 	if(pm == NULL) return FALSE;
 	
-	if(username == NULL || passworddata == NULL)
+	if(!username)
 	{
-		cem_add_to_log("Authentication failure, username or password not given", J_LOG_ERROR);
+		cem_add_to_log("Authentication failure, username not given", J_LOG_ERROR);
 		return LOGIN_INVALID_PARAMS;
 	}
 	
@@ -93,11 +94,12 @@ gint gems_profile_manager_authenticate_user(gchar* username, gchar* passworddata
 			cem_add_to_log("Authentication - unknown state when loading profile ?",J_LOG_ERROR);
 			break;
 	}
-	
+	if(!passworddata) printf("pass null\n");
 	// Create password from data
 	if((passwd = gems_security_create_password(passworddata,profilemanager_storage_get_password_salt(pm))) == NULL)
 	{
-		cem_add_to_log("Authentication failure, given password or salt is NULL.", J_LOG_ERROR);
+		gchar* logmsg = g_strdup_printf("Authentication failure, given %s is NULL.", passworddata ? "password" : "salt");
+		cem_add_to_log(logmsg, J_LOG_ERROR);
 		return LOGIN_CANNOT_INIT_PASSWD;
 	}
 	
@@ -175,7 +177,7 @@ gint gems_profile_manager_authenticate_user(gchar* username, gchar* passworddata
 	return LOGIN_OK;
 }
 
-gint gems_profile_manager_set_user(gchar* username)
+gint gems_profile_manager_set_user(const gchar* username)
 {
 	// if authenticated, cannot change user before logout, logout clears also the loaded data and sets load check to FALSE
 	if(profilemanager_is_authenticated(gems_get_profile_manager())) return CHANGE_USER_LOGOUT_REQUIRED;
@@ -269,7 +271,7 @@ gint gems_profile_manager_set_user(gchar* username)
 	}
 }
 
-gboolean gems_profile_manager_change_password(gchar* passworddata)
+gboolean gems_profile_manager_change_password(const gchar* passworddata)
 {
 	gboolean rval = TRUE;
 	ProfileManager* pm = gems_get_profile_manager();
@@ -298,8 +300,8 @@ gboolean gems_profile_manager_change_password(gchar* passworddata)
 		
 		guchar* pwdata = NULL;
 		guint pwdatalen = newpasslen;
-		if(newpasslen < AES_BLOCK_SIZE)	pwdata = (guchar*)g_malloc0(sizeof(guchar*)*AES_BLOCK_SIZE);
-		else pwdata = (guchar*)g_malloc0(sizeof(guchar*)*newpasslen);
+		if(newpasslen < AES_BLOCK_SIZE)	pwdata = g_new0(guchar,sizeof(guchar)*AES_BLOCK_SIZE);
+		else pwdata = g_new0(guchar,sizeof(guchar)*newpasslen);
 		
 		g_memmove(pwdata,passworddata,newpasslen);
 		
@@ -318,7 +320,7 @@ gboolean gems_profile_manager_change_password(gchar* passworddata)
 		guchar* newpass_dec = gems_security_decrypt_data(newpass_enc,&newpass_enclen);
 		newpasshashlen = newpass_enclen;
 		
-		guchar* newpass_dec_real = (guchar*)g_malloc0(sizeof(guchar*)*newpasslen);
+		guchar* newpass_dec_real = g_new0(guchar,sizeof(guchar)*newpasslen);
 		g_memmove(newpass_dec_real,newpass_dec,newpasslen);
 		guint newpass_real_len = newpasslen;
 		
@@ -437,7 +439,7 @@ gboolean gems_profile_manager_change_password(gchar* passworddata)
 	return rval;
 }
 
-gboolean gems_profile_manager_create_default_user_profile(gchar* passworddata, guint16 age)
+gboolean gems_profile_manager_create_default_user_profile(const gchar* passworddata, guint16 age)
 {
 	gboolean rval = TRUE;
 	GRand* grand = g_rand_new_with_seed(time(NULL));
