@@ -1147,6 +1147,9 @@ void gems_service_group_handle_force_group(gems_components* data, gems_connectio
 		data->service_group->group_info->theme = gems_connection_get_16(element,34);
 		track_id = gems_connection_get_16(element,36);
 
+		//set group as active
+		data->service_group->group_info->own_state=IN_GROUP;
+		//Inform CHUM of the game
 		chum_callback_game_starter(data->service_group->group_info, track_id);
 
 		logmsg = g_strdup_printf("gems_service_group_handle_force_group: got FORCE_GROUP with users owner = %u, peers[0] = %u", data->service_group->group_info->owner, data->service_group->group_info->peers[0]);
