@@ -88,10 +88,18 @@ GList* gems_service_jammo_process_list(GList* list, gboolean service)
 					{
 						/* CORRECT AMOUNT */
 						case sizeof(guint32):
-							logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): read length: %d", (service == TRUE ? 's' : 'c'), ntohl(packetlength));
+							logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): read length: %u", (service == TRUE ? 's' : 'c'), ntohl(packetlength));
 							cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 							g_free(logmsg);
-							gems_connection_add_32(element,ntohl(packetlength)); // Add length
+							if(ntohl(packetlength) > (JAMMO_NETWORK_BUFFER_MAX_SIZE - sizeof(guint32) - sizeof(guint16)))
+							{
+								logmsg = g_strdup_printf("gems_service_jammo_process_connections (%c): packet is too big, disconnecting.", (service == TRUE ? 's' : 'c'));
+								cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
+								g_free(logmsg);
+								ph_c_connection_disconnect(element->connection);
+								cleanup_required = TRUE;
+							}
+							else gems_connection_add_32(element,ntohl(packetlength)); // Add length
 							break;
 						case 0:
 						case -1:
