@@ -34,7 +34,7 @@ gboolean gems_service_mentor_process_request(gems_connection* element)
 
 gems_service_mentor* gems_service_mentor_init()
 {
-	gems_service_mentor* data = (gems_service_mentor*)g_malloc(sizeof(gems_service_mentor));
+	gems_service_mentor* data = g_new(gems_service_mentor,sizeof(gems_service_mentor));
 	
 	data->enabled = FALSE;
 	
