@@ -61,27 +61,27 @@ char* GetAuthorNameJSON( char* filepath ){
 FILE* execFindCommand(const char* filename){
 
 	char *command = NULL;	
-	int index;
+	int _index;
 	//"find " + sb->baseDirectory + " -name " + filename;
 	command = malloc( strlen("find ") + strlen(sb->baseDirectory) + strlen(" -name ") + strlen(filename) );
 
 	memcpy( command, "find ", strlen("find ") );
-	index = strlen("find ");
+	_index = strlen("find ");
 //	if( DEBUG )printf("\n%s", command );
 
-	memcpy( command+index, sb->baseDirectory , strlen(sb->baseDirectory) );
-	index += strlen(sb->baseDirectory);
+	memcpy( command+_index, sb->baseDirectory , strlen(sb->baseDirectory) );
+	_index += strlen(sb->baseDirectory);
 //	if( DEBUG )printf("\n%s", command );
 
-	memcpy( command+index, " -name ", strlen(" -name ") );
-	index += strlen(" -name ");
+	memcpy( command+_index, " -name ", strlen(" -name ") );
+	_index += strlen(" -name ");
 //	if( DEBUG )printf("\n%s", command );
 
-	memcpy( command+index, filename, strlen(filename) );	
+	memcpy( command+_index, filename, strlen(filename) );	
 //	if( DEBUG )printf("\n%s", command );
 
-	index += strlen(filename);
-	command[index] = '\0';
+	_index += strlen(filename);
+	command[_index] = '\0';
 	if( DEBUG )printf("final command:%s\n\n", command );
 
 	FILE* cmdLine = popen (command, "r");
