@@ -548,14 +548,14 @@ void gems_connection_localize_data_in_buffer(gems_connection* element)
 				case FORCE_GROUP:
 					gems_connection_add_32(element, g_ntohl(gems_connection_get_32(element, element->add_position)));
 					gems_connection_add_32(element, g_ntohl(gems_connection_get_32(element, element->add_position)));
-					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element, element->add_position)));
-					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element, element->add_position)));
-					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element, element->add_position)));
-					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element, element->add_position)));
 					gems_connection_add_32(element, g_ntohl(gems_connection_get_32(element, element->add_position)));
 					gems_connection_add_32(element, g_ntohl(gems_connection_get_32(element, element->add_position)));
 					gems_connection_add_32(element, g_ntohl(gems_connection_get_32(element, element->add_position)));
 					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element, element->add_position)));
+					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element, element->add_position)));
+					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element, element->add_position)));
+					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element, element->add_position)));
+					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element, element->add_position)));
 					break;
 				default:
 					break;
@@ -651,9 +651,9 @@ GList* gems_connection_error_add(GList* list, guint device_checksum, guint error
 {
 	gchar* logmsg = NULL;
 	gems_connection_error* item = NULL;
-	GRand* rand = NULL;
+	GRand* grand = NULL;
 	
-	if(errortype == ERROR_ALREADY_CONNECTED) rand = g_rand_new_with_seed(time(NULL));
+	if(errortype == ERROR_ALREADY_CONNECTED) grand = g_rand_new_with_seed(time(NULL));
 	
 	// Not found -> create new and add
 	if((item = gems_connection_error_get(list,device_checksum)) == NULL)
@@ -670,7 +670,7 @@ GList* gems_connection_error_add(GList* list, guint device_checksum, guint error
 		if(errortype == ERROR_ALREADY_CONNECTED)
 		{
 			item->already_connected = TRUE;
-			item->already_connected_delay = g_rand_double_range(rand,AC_DELAY_LOW,AC_DELAY_HIGH);
+			item->already_connected_delay = g_rand_double_range(grand,AC_DELAY_LOW,AC_DELAY_HIGH);
 		}
 		else
 		{
@@ -699,7 +699,7 @@ GList* gems_connection_error_add(GList* list, guint device_checksum, guint error
 			case ERROR_ALREADY_CONNECTED:
 			{
 				item->already_connected = TRUE;
-				item->already_connected_delay = g_rand_double_range(rand,AC_DELAY_LOW,AC_DELAY_HIGH);
+				item->already_connected_delay = g_rand_double_range(grand,AC_DELAY_LOW,AC_DELAY_HIGH);
 				break;
 			}
 			default:
@@ -711,7 +711,7 @@ GList* gems_connection_error_add(GList* list, guint device_checksum, guint error
 		g_free(logmsg);
 	}
 	
-	if(rand) g_rand_free(rand);
+	if(grand) g_rand_free(grand);
 	return list;
 }
 
