@@ -41,14 +41,14 @@ gboolean gems_check_illegal_characters(const gchar* data)
 	if(data == NULL) return FALSE;
 	
 	// Illegal characters
-	gchar illegal[ILLEGAL_CHAR_COUNT] = ILLEGAL_CHARS;
+	//gchar illegal[ILLEGAL_CHAR_COUNT] = ILLEGAL_CHARS;
 	
 	for(gint i = 0; i < ILLEGAL_CHAR_COUNT; i++)
 	{
 		for(gint j = 0; j < strlen(data); j++)
 		{
 			// found
-			if(data[j] == illegal[i]) return TRUE;
+			if(data[j] == ILLEGAL_CHARS[i]) return TRUE;
 		}
 	}
 	// Not found
