@@ -15,7 +15,7 @@
 
 // Define illegal chars here
 #define ILLEGAL_CHARS ",;.:*-_!#£$%&{}()=[]+?/\\\'\"\n\t^~"
-#define ILLEGAL_CHAR_COUNT strlen(ILLEGAL_CHARS)
+#define ILLEGAL_CHAR_COUNT G_N_ELEMENTS(ILLEGAL_CHARS)
 
 /* Check if all characters are integers/digits
  * 
