@@ -16,6 +16,8 @@
 #include <tangle.h>
 
 #include "../configure.h"
+#include "../cem/cem.h"
+
 enum {
 	PROP_0,
 	PROP_FILENAME,
@@ -176,8 +178,9 @@ guint64 jammo_sample_get_duration(JammoSample* sample) {
 
 	if (sample->priv->duration == JAMMO_DURATION_INVALID &&
 	   ((sample->priv->duration = jammo_meam_get_cached_duration(sample->priv->real_filename)) == JAMMO_DURATION_INVALID)) {
-		g_message("No cached duration for '%s', prerolling.", sample->priv->real_filename);
-
+		gchar* message = g_strdup_printf("No cached duration for sample '%s', prerolling.", sample->priv->real_filename);
+		cem_add_to_log(message,J_LOG_WARN);
+		g_free(message);
 		play_sample(sample, TRUE);
 	}
 	
