@@ -12,11 +12,19 @@
 #include <chum/jammo-chum.h>
 #include <chum/jammo-mentor.h>
 
+static void on_spoken2(JammoMentor* mentor, const gchar* speech, gboolean interrupted, gpointer user_data) {
+	jammo_mentor_speak_and_highlight(mentor, "test_sound.wav", 300.0, -50.0);
+}
+
+static void on_spoken1(JammoMentor* mentor, const gchar* speech, gboolean interrupted, gpointer user_data) {
+	jammo_mentor_highlight_with_callback(mentor, 50.0, 100.0, 3000, on_spoken2, NULL);
+}
+
 static gboolean activate_mentor(gpointer user_data) {
 	JammoMentor* mentor;
 	
 	mentor = JAMMO_MENTOR(user_data);
-	jammo_mentor_speak_and_highlight(mentor, "test_sound.wav", 100.0, -10.0);
+	jammo_mentor_speak_and_highlight_with_callback(mentor, "test_sound.wav", 100.0, -10.0, on_spoken1, NULL);
 
 	return FALSE;
 }
